@@ -3,11 +3,11 @@ import sys
 from typing import List, Optional, Tuple
 
 import click
+from mythx_models.response import AnalysisInputResponse, DetectedIssuesResponse
 
 from mythx_cli.formatter import FORMAT_RESOLVER, util
 from mythx_cli.formatter.base import BaseFormatter
 from mythx_cli.util import write_or_print
-from mythx_models.response import AnalysisInputResponse, DetectedIssuesResponse
 
 LOGGER = logging.getLogger("mythx-cli")
 
@@ -49,6 +49,7 @@ def analysis_report(
     :param min_severity: Ignore SWC IDs below the designated level
     :param swc_blacklist: A comma-separated list of SWC IDs to ignore
     :param swc_whitelist: A comma-separated list of SWC IDs to include
+    :param table_sort_key: The column to sort the default table output by
     :return:
     """
 
@@ -76,6 +77,12 @@ def analysis_report(
         resp.uuid = uuid
         issues_list.append((resp, inp))
 
-    LOGGER.debug(f"{uuid}: Printing report for {len(issues_list)} issue items")
-    write_or_print(formatter.format_detected_issues(issues_list))
+    LOGGER.debug(
+        f"{uuid}: Printing report for {len(issues_list)} issue items with sort key \"{ctx['table_sort_key']}\""
+    )
+    write_or_print(
+        formatter.format_detected_issues(
+            issues_list, table_sort_key=ctx["table_sort_key"]
+        )
+    )
     sys.exit(ctx["retval"])
