@@ -1,7 +1,6 @@
 import logging
 import sys
 import time
-from glob import glob
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
 
@@ -14,7 +13,7 @@ from mythx_models.response import (
 from pythx.middleware.group_data import GroupDataMiddleware
 from pythx.middleware.property_checking import PropertyCheckingMiddleware
 
-from mythx_cli.analyze.solidity import SolidityJob, walk_solidity_files
+from mythx_cli.analyze.solidity import SolidityJob
 from mythx_cli.analyze.truffle import TruffleJob
 from mythx_cli.analyze.util import (
     ScenarioMode,
@@ -37,7 +36,12 @@ LOGGER = logging.getLogger("mythx-cli")
     default=None,
     help="Submit the job and print the UUID, or wait for execution to finish",
 )
-@click.option("--mode", type=click.Choice(["quick", "standard", "deep"]), default=None)
+@click.option(
+    "--mode",
+    type=click.Choice(["quick", "standard", "deep"]),
+    help="The MythX analysis mode to use",
+    default=None,
+)
 @click.option(
     "--create-group",
     is_flag=True,
@@ -80,6 +84,12 @@ LOGGER = logging.getLogger("mythx-cli")
     help="The solc version to use for compilation",
     default=None,
 )
+@click.option(
+    "--solc-path",
+    type=click.Path(exists=True),
+    default=None,
+    help="Path to a custom solc executable",
+)
 @click.option(
     "--include",
     type=click.STRING,
@@ -132,6 +142,7 @@ def analyze(
     swc_blacklist: str,
     swc_whitelist: str,
     solc_version: str,
+    solc_path: str,
     include: Tuple[str],
     remap_import: Tuple[str],
     check_properties: bool,
@@ -154,6 +165,7 @@ def analyze(
     :param swc_blacklist: A comma-separated list of SWC IDs to ignore
     :param swc_whitelist: A comma-separated list of SWC IDs to include
     :param solc_version: The solc version to use for Solidity compilation
+    :param solc_path: The path to a custom solc executable
     :param include: List of contract names to send - exclude everything else
     :param remap_import: List of import remappings to pass on to solc
     :param check_properties: Enable property verification mode
@@ -209,14 +221,19 @@ def analyze(
     for scenario, element in mode_list:
         if scenario == ScenarioMode.TRUFFLE:
             job = TruffleJob(element)
-            job.generate_payloads()
+            job.generate_payloads(
+                enable_scribble=enable_scribble,
+                remappings=remap_import,
+                scribble_path=scribble_path,
+            )
             jobs.extend(job.payloads)
         elif scenario == ScenarioMode.SOLIDITY_DIR:
             # recursively enumerate sol files if not a truffle project
             LOGGER.debug(f"Identified {element} as directory containing Solidity files")
             jobs.extend(
-                walk_solidity_files(
-                    solc_version,
+                SolidityJob.walk_solidity_files(
+                    solc_version=solc_version,
+                    solc_path=solc_path,
                     base_path=element,
                     remappings=remap_import,
                     enable_scribble=enable_scribble,
@@ -233,6 +250,7 @@ def analyze(
             job = SolidityJob(Path(file_path))
             job.generate_payloads(
                 version=solc_version,
+                solc_path=solc_path,
                 contract=contract or None,
                 remappings=remap_import,
                 enable_scribble=enable_scribble,
@@ -316,6 +334,12 @@ def analyze(
         resp.uuid = uuid
         issues_list.append((resp, inp))
 
-    LOGGER.debug(f"Printing report for {len(issues_list)} issue items")
-    write_or_print(formatter.format_detected_issues(issues_list))
+    LOGGER.debug(
+        f"Printing report for {len(issues_list)} issue items with sort key \"{ctx['table_sort_key']}\""
+    )
+    write_or_print(
+        formatter.format_detected_issues(
+            issues_list, table_sort_key=ctx["table_sort_key"]
+        )
+    )
     sys.exit(ctx["retval"])
