@@ -53,7 +53,8 @@ class JSONFormatter(BaseFormatter):
     def format_detected_issues(
         issues_list: List[
             Tuple[DetectedIssuesResponse, Optional[AnalysisInputResponse]]
-        ]
+        ],
+        **kwargs,
     ) -> str:
         """Format an issue report response as compressed JSON."""
 
@@ -71,7 +72,7 @@ class PrettyJSONFormatter(BaseFormatter):
     """The pretty-printing JSON formatter.
 
     It works exactly as the JSON formatter, with the difference that the
-    string-encoded JSON object is indented with two spaces for each
+    string- encoded JSON object is indented with two spaces for each
     level, and the keys are sorted in alphabetical order.
     """
 
@@ -116,7 +117,8 @@ class PrettyJSONFormatter(BaseFormatter):
     def format_detected_issues(
         issues_list: List[
             Tuple[DetectedIssuesResponse, Optional[AnalysisInputResponse]]
-        ]
+        ],
+        **kwargs,
     ) -> str:
         """Format an issue report response as pretty-printed JSON."""
 
