@@ -1,9 +1,9 @@
 import json
 
 from click.testing import CliRunner
+from mythx_models.response import AnalysisInputResponse, DetectedIssuesResponse
 
 from mythx_cli.cli import cli
-from mythx_models.response import AnalysisInputResponse, DetectedIssuesResponse
 
 from .common import get_test_case, mock_context
 
@@ -15,7 +15,6 @@ ISSUES_RESPONSE = get_test_case(
 )
 ISSUES_SIMPLE = get_test_case("testdata/detected-issues-simple.txt", raw=True)
 ISSUES_TABLE = get_test_case("testdata/detected-issues-table.txt", raw=True)
-ISSUES_SONAR = get_test_case("testdata/detected-issues-sonar.json")
 
 
 def test_report_tabular():
@@ -95,84 +94,6 @@ def test_report_tabular_filter():
         assert result.exit_code == 0
 
 
-def test_report_sonar():
-    runner = CliRunner()
-    with mock_context():
-        result = runner.invoke(
-            cli,
-            [
-                "--format",
-                "sonar",
-                "analysis",
-                "report",
-                "ab9092f7-54d0-480f-9b63-1bb1508280e2",
-            ],
-        )
-
-        assert json.loads(result.output) == ISSUES_SONAR
-        assert result.exit_code == 0
-
-
-def test_report_sonar_blacklist():
-    runner = CliRunner()
-    with mock_context():
-        result = runner.invoke(
-            cli,
-            [
-                "--format",
-                "sonar",
-                "analysis",
-                "report",
-                "--swc-blacklist",
-                "SWC-110",
-                "ab9092f7-54d0-480f-9b63-1bb1508280e2",
-            ],
-        )
-
-        assert all(x["forRule"] != "SWC-110" for x in json.loads(result.output))
-        assert result.exit_code == 0
-
-
-def test_report_sonar_whitelist():
-    runner = CliRunner()
-    with mock_context():
-        result = runner.invoke(
-            cli,
-            [
-                "--format",
-                "sonar",
-                "analysis",
-                "report",
-                "--swc-whitelist",
-                "SWC-110",
-                "ab9092f7-54d0-480f-9b63-1bb1508280e2",
-            ],
-        )
-
-        assert all(x["forRule"] == "SWC-110" for x in json.loads(result.output))
-        assert result.exit_code == 0
-
-
-def test_report_sonar_filter():
-    runner = CliRunner()
-    with mock_context():
-        result = runner.invoke(
-            cli,
-            [
-                "--format",
-                "sonar",
-                "analysis",
-                "report",
-                "--min-severity",
-                "high",
-                "ab9092f7-54d0-480f-9b63-1bb1508280e2",
-            ],
-        )
-
-        assert all(x["forRule"] != "SWC-110" for x in json.loads(result.output))
-        assert result.exit_code == 0
-
-
 def test_report_json():
     runner = CliRunner()
     with mock_context():
